@@ -15,11 +15,8 @@ import autograd.numpy as np
 from surpyval import nonparametric as nonp
 from .parametric_fitter import ParametricFitter
 from .parametric import Parametric
-from .offset_parametric import OffsetParametric
-from .offset_parametric import ParametricO
 
 from .weibull import Weibull
-from .weibull3p import Weibull3p
 from .gumbel import Gumbel
 from .exponential import Exponential
 from .expo_weibull import ExpoWeibull
@@ -35,4 +32,5 @@ from .loglogistic import LogLogistic
 from .mixture_model import MixtureModel
 
 from .lfp import LFP
+from .dist_from_hazard import Distribution
 
